summaryrefslogtreecommitdiffstats
diff options
context:
space:
mode:
authorToby Tomkins <toby.tomkins@nokia.com>2010-12-07 16:36:49 +1000
committerToby Tomkins <toby.tomkins@nokia.com>2010-12-07 16:36:49 +1000
commitf31b25977d3db47da89ef606316dbf532fbf3dab (patch)
tree834a3510887c2bbbe7b8308a74c7c75f40d10188
parent25c9d8aea389cbff891a23da7fbaf6175a8fcaf7 (diff)
Fixed spelling mistakes.
Reviewed-by: Jason McDonald
-rw-r--r--examples/calendardemo/src/daypage.cpp2
-rw-r--r--examples/calendardemo/src/eventoccurrenceeditpage.cpp2
-rw-r--r--plugins/contacts/maemo5/qcontactmaemo5backend.cpp2
-rw-r--r--plugins/declarative/contacts/details/qdeclarativecontactonlineaccount_p.h2
-rw-r--r--plugins/declarative/multimedia/qdeclarativecamera.cpp2
-rw-r--r--plugins/declarative/systeminfo/qdeclarativescreensaver.cpp2
-rw-r--r--plugins/feedback/immersion/qfeedback.cpp2
-rw-r--r--plugins/multimedia/symbian/ecam/s60imagecapturesession.cpp2
-rw-r--r--plugins/multimedia/symbian/ecam/s60videocapturesession.cpp2
-rw-r--r--plugins/multimedia/symbian/openmaxal/mediaplayer/xaplaysessionimpl.cpp2
-rw-r--r--plugins/multimedia/v4l/radio/v4lradiocontrol.cpp2
-rw-r--r--plugins/multimedia/v4l/radio/v4lradiocontrol_maemo5.cpp2
-rw-r--r--plugins/organizer/maemo5/qorganizerasynchprocess.cpp4
-rw-r--r--plugins/organizer/maemo5/qorganizermaemo5.cpp2
-rw-r--r--plugins/organizer/symbian/organizeritemrequestserviceprovider.cpp2
-rw-r--r--plugins/organizer/symbian/qorganizersymbian.cpp6
-rw-r--r--plugins/organizer/symbian/tsrc/tst_itemoccurrence/tst_itemoccurrence.cpp32
-rw-r--r--plugins/organizer/symbian/tsrc/tst_itemsortfilter/tst_itemsortfilter.cpp4
-rw-r--r--plugins/organizer/symbian/tsrc/tst_recurringitems/tst_recurringitems.cpp20
-rw-r--r--plugins/organizer/symbian/tsrc/tst_symbianom/tst_symbianom.cpp4
-rw-r--r--src/bearer/qnetworkconfigmanager_s60_p.cpp2
-rw-r--r--src/bearer/qnetworksession_s60_p.cpp4
-rw-r--r--src/contacts/engines/qcontactmemorybackend.cpp4
-rw-r--r--src/gallery/qgalleryqueryrequest.cpp2
-rw-r--r--src/messaging/eventloggerengine_maemo.cpp2
-rw-r--r--src/messaging/modestengine_maemo.cpp2
-rw-r--r--src/messaging/qmessagefilter_win.cpp6
-rw-r--r--src/messaging/qmessageservice.cpp2
-rw-r--r--src/messaging/qmessageservice_win.cpp4
-rw-r--r--src/messaging/qmtmengine_symbian.cpp2
-rw-r--r--src/messaging/tpsessionaccount.cpp2
-rw-r--r--src/messaging/tpsessionchannel.cpp2
-rw-r--r--src/messaging/win32wce/qmailmessage.cpp4
-rw-r--r--src/messaging/win32wce/qmailmessagefwd.cpp2
-rw-r--r--src/multimedia/qcamera.cpp8
-rw-r--r--src/multimedia/qcameracontrol.cpp2
-rw-r--r--src/multimedia/qcameraexposure.cpp2
-rw-r--r--src/multimedia/qcameraexposurecontrol.cpp6
-rw-r--r--src/multimedia/qcamerafocus.cpp4
-rw-r--r--src/multimedia/qcamerafocuscontrol.cpp2
-rw-r--r--src/multimedia/qcameraimagecapture.cpp6
-rw-r--r--src/multimedia/qcameraimageprocessingcontrol.cpp2
-rw-r--r--src/multimedia/qmediabindableinterface.cpp2
-rw-r--r--src/multimedia/qmediaobject.cpp2
-rw-r--r--src/multimedia/qmediaplayer.cpp2
-rw-r--r--src/multimedia/qmediaplayercontrol.cpp2
-rw-r--r--src/multimedia/qmediaplaylistcontrol.cpp6
-rw-r--r--src/multimedia/qmediaplaylistioplugin.cpp2
-rw-r--r--src/multimedia/qmediaplaylistprovider.cpp4
-rw-r--r--src/multimedia/qmediaplaylistsourcecontrol.cpp2
-rw-r--r--src/multimedia/qmediastreamscontrol.cpp4
-rw-r--r--src/multimedia/qradiotunercontrol.cpp2
52 files changed, 99 insertions, 99 deletions
diff --git a/examples/calendardemo/src/daypage.cpp b/examples/calendardemo/src/daypage.cpp
index 145bea9730..0f7023c300 100644
--- a/examples/calendardemo/src/daypage.cpp
+++ b/examples/calendardemo/src/daypage.cpp
@@ -125,7 +125,7 @@ void DayPage::refresh()
QString time = eventTime.startDateTime().time().toString("hh:mm");
QListWidgetItem* listItem = new QListWidgetItem();
if (item.type() == QOrganizerItemType::TypeEventOccurrence)
- listItem->setText(QString("Event occurance:%1-%2").arg(time).arg(item.displayLabel()));
+ listItem->setText(QString("Event occurrence:%1-%2").arg(time).arg(item.displayLabel()));
else
listItem->setText(QString("Event:%1-%2").arg(time).arg(item.displayLabel()));
QVariant data = QVariant::fromValue<QOrganizerItem>(item);
diff --git a/examples/calendardemo/src/eventoccurrenceeditpage.cpp b/examples/calendardemo/src/eventoccurrenceeditpage.cpp
index ae5970c01c..24e0a48198 100644
--- a/examples/calendardemo/src/eventoccurrenceeditpage.cpp
+++ b/examples/calendardemo/src/eventoccurrenceeditpage.cpp
@@ -174,7 +174,7 @@ void EventOccurrenceEditPage::saveOrNextClicked()
void EventOccurrenceEditPage::showEvent(QShowEvent *event)
{
- window()->setWindowTitle("Edit event occurence");
+ window()->setWindowTitle("Edit event occurrence");
QWidget::showEvent(event);
}
diff --git a/plugins/contacts/maemo5/qcontactmaemo5backend.cpp b/plugins/contacts/maemo5/qcontactmaemo5backend.cpp
index c237276f3e..974696dc38 100644
--- a/plugins/contacts/maemo5/qcontactmaemo5backend.cpp
+++ b/plugins/contacts/maemo5/qcontactmaemo5backend.cpp
@@ -190,7 +190,7 @@ QList<QContactLocalId> QContactMaemo5Engine::contactIds(const QContactFilter& fi
QList<QContact> QContactMaemo5Engine::contacts(const QContactFilter & filter, const QList<QContactSortOrder> & sortOrders, const QContactFetchHint & fetchHint,
QContactManager::Error* error ) const
{
- Q_UNUSED(fetchHint); // no optimisations currently, ignore the fetchhint.
+ Q_UNUSED(fetchHint); // no optimizations currently, ignore the fetchhint.
Q_CHECK_PTR(d->m_abook);
QList<QContact> rtn;
diff --git a/plugins/declarative/contacts/details/qdeclarativecontactonlineaccount_p.h b/plugins/declarative/contacts/details/qdeclarativecontactonlineaccount_p.h
index 11ba1acdd8..134cbf3de9 100644
--- a/plugins/declarative/contacts/details/qdeclarativecontactonlineaccount_p.h
+++ b/plugins/declarative/contacts/details/qdeclarativecontactonlineaccount_p.h
@@ -147,7 +147,7 @@ public:
savedList << QContactOnlineAccount::SubTypeVideoShare;
break;
default:
- //qWarning unkown subtype
+ //qWarning unknown subtype
break;
}
diff --git a/plugins/declarative/multimedia/qdeclarativecamera.cpp b/plugins/declarative/multimedia/qdeclarativecamera.cpp
index 899a3c80d5..fd574bebec 100644
--- a/plugins/declarative/multimedia/qdeclarativecamera.cpp
+++ b/plugins/declarative/multimedia/qdeclarativecamera.cpp
@@ -594,7 +594,7 @@ void QDeclarativeCamera::setManualWhiteBalance(int colorTemp) const
The locked state usually means the requested parameter stays the same,
except of the cases when the parameter is requested to be constantly updated.
- For example in continous focusing mode, the focus is considered locked as long
+ For example in continuous focusing mode, the focus is considered locked as long
and the object is in focus, even while the actual focusing distance may be constantly changing.
*/
diff --git a/plugins/declarative/systeminfo/qdeclarativescreensaver.cpp b/plugins/declarative/systeminfo/qdeclarativescreensaver.cpp
index 895910466d..9f6db4288a 100644
--- a/plugins/declarative/systeminfo/qdeclarativescreensaver.cpp
+++ b/plugins/declarative/systeminfo/qdeclarativescreensaver.cpp
@@ -82,7 +82,7 @@ void QDeclarativeScreenSaver::setScreenSaverDelayed(bool on)
/*!
\qmlproperty string ScreenSaver::screenSaverDelayed
- Returns whether the screensaver has been supressed, or not.
+ Returns whether the screensaver has been suppressed, or not.
*/
bool QDeclarativeScreenSaver::screenSaverDelayed()
diff --git a/plugins/feedback/immersion/qfeedback.cpp b/plugins/feedback/immersion/qfeedback.cpp
index 331e01b74a..a952a548db 100644
--- a/plugins/feedback/immersion/qfeedback.cpp
+++ b/plugins/feedback/immersion/qfeedback.cpp
@@ -182,7 +182,7 @@ VibeInt32 QFeedbackImmersion::handleForActuator(int actId)
if (VIBE_IS_INVALID_DEVICE_HANDLE(actuatorHandles.at(actId))) {
ImmVibeOpenDevice(actId, &actuatorHandles[actId] );
- //temporary solution: provide a proto dev licence key
+ //temporary solution: provide a proto dev license key
ImmVibeSetDevicePropertyString(actuatorHandles.at(actId), VIBE_DEVPROPTYPE_LICENSE_KEY, "IMWPROTOSJZF4EH6KWVUK8HAP5WACT6Q");
}
}
diff --git a/plugins/multimedia/symbian/ecam/s60imagecapturesession.cpp b/plugins/multimedia/symbian/ecam/s60imagecapturesession.cpp
index e6db0ab257..26ae5b7e7c 100644
--- a/plugins/multimedia/symbian/ecam/s60imagecapturesession.cpp
+++ b/plugins/multimedia/symbian/ecam/s60imagecapturesession.cpp
@@ -455,7 +455,7 @@ QCameraImageCapture::Error S60ImageCaptureSession::fromSymbianErrorToQtMultimedi
return QCameraImageCapture::ResourceError; // No resources available
default:
- return QCameraImageCapture::ResourceError; // Other error has occured
+ return QCameraImageCapture::ResourceError; // Other error has occurred
}
}
diff --git a/plugins/multimedia/symbian/ecam/s60videocapturesession.cpp b/plugins/multimedia/symbian/ecam/s60videocapturesession.cpp
index ffb3d3dba7..94ace3239a 100644
--- a/plugins/multimedia/symbian/ecam/s60videocapturesession.cpp
+++ b/plugins/multimedia/symbian/ecam/s60videocapturesession.cpp
@@ -167,7 +167,7 @@ QMediaRecorder::Error S60VideoCaptureSession::fromSymbianErrorToQtMultimediaErro
return QMediaRecorder::ResourceError; // Not able to use camera/recorder resources
default:
- return QMediaRecorder::ResourceError; // Other error has occured
+ return QMediaRecorder::ResourceError; // Other error has occurred
}
}
diff --git a/plugins/multimedia/symbian/openmaxal/mediaplayer/xaplaysessionimpl.cpp b/plugins/multimedia/symbian/openmaxal/mediaplayer/xaplaysessionimpl.cpp
index 9464b94671..88a06807f6 100644
--- a/plugins/multimedia/symbian/openmaxal/mediaplayer/xaplaysessionimpl.cpp
+++ b/plugins/multimedia/symbian/openmaxal/mediaplayer/xaplaysessionimpl.cpp
@@ -447,7 +447,7 @@ TInt XAPlaySessionImpl::load(const TDesC& aURI)
if(mbMetadataAvailable) {
keyMap.clear();
extendedKeyMap.clear();
- setupMetaData(); //done everytime source is changed
+ setupMetaData(); //done every time source is changed
}
else { //send signal for seekable
mParent.cbSeekableChanged(ETrue);
diff --git a/plugins/multimedia/v4l/radio/v4lradiocontrol.cpp b/plugins/multimedia/v4l/radio/v4lradiocontrol.cpp
index fc1a76026a..1b698279a5 100644
--- a/plugins/multimedia/v4l/radio/v4lradiocontrol.cpp
+++ b/plugins/multimedia/v4l/radio/v4lradiocontrol.cpp
@@ -434,7 +434,7 @@ bool V4LRadioControl::initRadio()
fd = ::open("/dev/radio0", O_RDWR);
if(fd != -1) {
- // Capabilites
+ // Capabilities
memset( &cap, 0, sizeof( cap ) );
if(::ioctl(fd, VIDIOC_QUERYCAP, &cap ) >= 0) {
if(((cap.capabilities & V4L2_CAP_RADIO) == 0) && ((cap.capabilities & V4L2_CAP_AUDIO) == 0))
diff --git a/plugins/multimedia/v4l/radio/v4lradiocontrol_maemo5.cpp b/plugins/multimedia/v4l/radio/v4lradiocontrol_maemo5.cpp
index e8fcc6d711..f3dea9d630 100644
--- a/plugins/multimedia/v4l/radio/v4lradiocontrol_maemo5.cpp
+++ b/plugins/multimedia/v4l/radio/v4lradiocontrol_maemo5.cpp
@@ -697,7 +697,7 @@ bool V4LRadioControl::initRadio()
fd = ::open("/dev/radio1", O_RDWR);
if(fd != -1) {
- // Capabilites
+ // Capabilities
memset(&cap, 0, sizeof(cap));
if(::ioctl(fd, VIDIOC_QUERYCAP, &cap ) >= 0) {
available = true;
diff --git a/plugins/organizer/maemo5/qorganizerasynchprocess.cpp b/plugins/organizer/maemo5/qorganizerasynchprocess.cpp
index acb47f93e2..9d1cc8be04 100644
--- a/plugins/organizer/maemo5/qorganizerasynchprocess.cpp
+++ b/plugins/organizer/maemo5/qorganizerasynchprocess.cpp
@@ -171,12 +171,12 @@ bool OrganizerAsynchProcess::waitForRequestFinished(QOrganizerAbstractRequest *r
m_timeoutMutex.lock();
if (!m_activeRequests.contains(req)) {
- // timeout occured
+ // timeout occurred
m_timeoutMutex.unlock();
return false;
}
else {
- // timeout not occured
+ // timeout not occurred
m_activeRequests.remove(req);
// cancel and remove timer
diff --git a/plugins/organizer/maemo5/qorganizermaemo5.cpp b/plugins/organizer/maemo5/qorganizermaemo5.cpp
index bcdc046776..bd0aea7f3b 100644
--- a/plugins/organizer/maemo5/qorganizermaemo5.cpp
+++ b/plugins/organizer/maemo5/qorganizermaemo5.cpp
@@ -1809,7 +1809,7 @@ QOrganizerItem QOrganizerItemMaemo5Engine::parentOf(CCalendar *cal, QOrganizerIt
QList<QOrganizerItem> parentCandidateOccurrences =
internalItemOccurrences(*parentCandidateEvent, periodStart, periodEnd, 0, error);
if (*error != QOrganizerManager::NoError)
- return QOrganizerItem(); // error occured
+ return QOrganizerItem(); // error occurred
// Because the period was set, it's enough to just check if we got any
if (!parentCandidateOccurrences.isEmpty()) {
diff --git a/plugins/organizer/symbian/organizeritemrequestserviceprovider.cpp b/plugins/organizer/symbian/organizeritemrequestserviceprovider.cpp
index 3814461171..a2c8a470d1 100644
--- a/plugins/organizer/symbian/organizeritemrequestserviceprovider.cpp
+++ b/plugins/organizer/symbian/organizeritemrequestserviceprovider.cpp
@@ -557,7 +557,7 @@ void COrganizerItemRequestsServiceProvider::DoCancel()
// Call if RunL leaves
TInt COrganizerItemRequestsServiceProvider::RunError(TInt aError)
{
- // Operation not successfull
+ // Operation not successful
// Generate error map
QOrganizerManager::Error error(QOrganizerManager::NoError);
iOrganizerItemManagerEngine.transformError(aError, &error);
diff --git a/plugins/organizer/symbian/qorganizersymbian.cpp b/plugins/organizer/symbian/qorganizersymbian.cpp
index 56dbe6609e..7f31edc3c8 100644
--- a/plugins/organizer/symbian/qorganizersymbian.cpp
+++ b/plugins/organizer/symbian/qorganizersymbian.cpp
@@ -383,7 +383,7 @@ QList<QOrganizerItem> QOrganizerItemSymbianEngine::itemOccurrencesL(
QOrganizerManager::Error error;
QOrganizerItem parentItem = this->item(parentItemId, QOrganizerItemFetchHint(), &error);
if (error != QOrganizerManager::NoError)
- return QList<QOrganizerItem>(); // return an empty occurence list if parent item is not found
+ return QList<QOrganizerItem>(); // return an empty occurrence list if parent item is not found
// Verify time range
if (periodStart.isValid() && periodEnd.isValid() && periodEnd < periodStart)
@@ -588,7 +588,7 @@ QList<QOrganizerItemId> QOrganizerItemSymbianEngine::itemIdsL(
// Time range is not defined. So we can just return all entries.
// NOTE: this a lot faster than using instance view
- // Get all entrys
+ // Get all entries
TCalTime minTime;
minTime.SetTimeUtcL(TCalTime::MinTime());
RArray<TCalLocalUid> ids;
@@ -606,7 +606,7 @@ QList<QOrganizerItemId> QOrganizerItemSymbianEngine::itemIdsL(
// Time range is defined so we need to use instance view to find
// all entries in the range. For example an item which starts before
- // periodStart might have an occurence in the range. We cannot catch
+ // periodStart might have an occurrence in the range. We cannot catch
// that through CCalEntryView.
// NOTE: If the client does not define periodEnd we might get
// a huge amount of instances!
diff --git a/plugins/organizer/symbian/tsrc/tst_itemoccurrence/tst_itemoccurrence.cpp b/plugins/organizer/symbian/tsrc/tst_itemoccurrence/tst_itemoccurrence.cpp
index f73866bdbe..5b6b893fde 100644
--- a/plugins/organizer/symbian/tsrc/tst_itemoccurrence/tst_itemoccurrence.cpp
+++ b/plugins/organizer/symbian/tsrc/tst_itemoccurrence/tst_itemoccurrence.cpp
@@ -792,20 +792,20 @@ void tst_ItemOccurrence::daylightSavingTime()
// Verify that event occurs the same time every month
QList<QOrganizerItem> events = m_om->itemOccurrences(event, event.startDateTime(), QDateTime(rule.limitDate()));
QVERIFY(events.count() == 12);
- foreach(QOrganizerEventOccurrence occurence, events) {
+ foreach(QOrganizerEventOccurrence occurrence, events) {
//qDebug() << "event occurrence:";
- //qDebug() << "\tstart time utc :" << occurence.startDateTime().toUTC();
- //qDebug() << "\tstart time local :" << occurence.startDateTime().toLocalTime();
- //qDebug() << "\tend time utc :" << occurence.endDateTime().toUTC();
- //qDebug() << "\tend time local :" << occurence.endDateTime().toLocalTime();
-
- QVERIFY(occurence.startDateTime().toUTC().time() == startDateTime.toUTC().time());
- QVERIFY(occurence.endDateTime().toUTC().time() == endDateTime.toUTC().time());
- QVERIFY(occurence.startDateTime().toLocalTime().time() == startDateTime.toLocalTime().time());
- QVERIFY(occurence.endDateTime().toLocalTime().time() == endDateTime.toLocalTime().time());
- QVERIFY(occurence.startDateTime().toLocalTime().date().day() == startDateTime.toLocalTime().date().day());
- QVERIFY(occurence.endDateTime().toLocalTime().date().day() == endDateTime.toLocalTime().date().day());
+ //qDebug() << "\tstart time utc :" << occurrence.startDateTime().toUTC();
+ //qDebug() << "\tstart time local :" << occurrence.startDateTime().toLocalTime();
+ //qDebug() << "\tend time utc :" << occurrence.endDateTime().toUTC();
+ //qDebug() << "\tend time local :" << occurrence.endDateTime().toLocalTime();
+
+ QVERIFY(occurrence.startDateTime().toUTC().time() == startDateTime.toUTC().time());
+ QVERIFY(occurrence.endDateTime().toUTC().time() == endDateTime.toUTC().time());
+ QVERIFY(occurrence.startDateTime().toLocalTime().time() == startDateTime.toLocalTime().time());
+ QVERIFY(occurrence.endDateTime().toLocalTime().time() == endDateTime.toLocalTime().time());
+ QVERIFY(occurrence.startDateTime().toLocalTime().date().day() == startDateTime.toLocalTime().date().day());
+ QVERIFY(occurrence.endDateTime().toLocalTime().date().day() == endDateTime.toLocalTime().date().day());
}
}
@@ -829,11 +829,11 @@ void tst_ItemOccurrence::leapYear()
// Verify
QList<QOrganizerItem> events = m_om->itemOccurrences(event, event.startDateTime(), QDateTime(rule.limitDate()));
QVERIFY(events.count() == 9);
- foreach(QOrganizerEventOccurrence occurence, events) {
- if (occurence.startDateTime().date().year() % 4 == 0)
- QVERIFY(occurence.startDateTime().date().day() == 29); // leap year
+ foreach(QOrganizerEventOccurrence occurrence, events) {
+ if (occurrence.startDateTime().date().year() % 4 == 0)
+ QVERIFY(occurrence.startDateTime().date().day() == 29); // leap year
else
- QVERIFY(occurence.startDateTime().date().day() == 28); // normal year
+ QVERIFY(occurrence.startDateTime().date().day() == 28); // normal year
}
}
diff --git a/plugins/organizer/symbian/tsrc/tst_itemsortfilter/tst_itemsortfilter.cpp b/plugins/organizer/symbian/tsrc/tst_itemsortfilter/tst_itemsortfilter.cpp
index 2dd9e2b3e8..e53f5d060d 100644
--- a/plugins/organizer/symbian/tsrc/tst_itemsortfilter/tst_itemsortfilter.cpp
+++ b/plugins/organizer/symbian/tsrc/tst_itemsortfilter/tst_itemsortfilter.cpp
@@ -251,7 +251,7 @@ void tst_itemSortFilter::filterItems()
QFETCH(int, mgrIndex);
QFETCH(QString, matchingItemsStr);
- // Verify item occurences
+ // Verify item occurrences
QList<QOrganizerItem> actualItems = m_managers.at(mgrIndex)->items(filter);
// Cannot use id comparison, since no ids are available for occurrences
QCOMPARE(actualItems.count(), matchingItemsStr.count());
@@ -320,7 +320,7 @@ void tst_itemSortFilter::sortItems()
QFETCH(int, mgrIndex);
QFETCH(QString, matchingItemsStr);
- // Verify item occurences
+ // Verify item occurrences
QList<QOrganizerItem> actualItems = m_managers.at(mgrIndex)->items(QOrganizerItemFilter(), sortOrderList);
// Cannot use id comparison, since no ids are available for occurrences
QCOMPARE(actualItems.count(), matchingItemsStr.count());
diff --git a/plugins/organizer/symbian/tsrc/tst_symbianom/tst_symbianom.cpp b/plugins/organizer/symbian/tsrc/tst_symbianom/tst_symbianom.cpp
index 1c796023cc..b427957791 100644
--- a/plugins/organizer/symbian/tsrc/tst_symbianom/tst_symbianom.cpp
+++ b/plugins/organizer/symbian/tsrc/tst_symbianom/tst_symbianom.cpp
@@ -371,7 +371,7 @@ void tst_SymbianOm::fetchItemIds()
// Get items in the range
actualIds = m_om->itemIds(dateTime.addDays(1), dateTime.addDays(8));
QVERIFY(m_om->error() == QOrganizerManager::NoError);
- QVERIFY(actualIds.contains(event.id())); // one occurence is in time range
+ QVERIFY(actualIds.contains(event.id())); // one occurrence is in time range
QVERIFY(!actualIds.contains(todo.id())); // should not be found because out of time range
}
@@ -857,7 +857,7 @@ void tst_SymbianOm::outOfMemory()
event.setRecurrenceRule(rule);
QVERIFY(m_om->saveItem(&event));
- // This will produce ~2500000 occurences. No way it will fit in memory
+ // This will produce ~2500000 occurrences. No way it will fit in memory
QList<QOrganizerItem> items = m_om->items(dateTime, QDateTime());
QVERIFY(m_om->error() == QOrganizerManager::OutOfMemoryError);
diff --git a/src/bearer/qnetworkconfigmanager_s60_p.cpp b/src/bearer/qnetworkconfigmanager_s60_p.cpp
index 83e663a41a..00ebcee534 100644
--- a/src/bearer/qnetworkconfigmanager_s60_p.cpp
+++ b/src/bearer/qnetworkconfigmanager_s60_p.cpp
@@ -883,7 +883,7 @@ void QNetworkConfigurationManagerPrivate::stopCommsDatabaseNotifications()
void QNetworkConfigurationManagerPrivate::RunL()
{
if (iStatus != KErrCancel) {
- // By default, start relistening notifications. Stop only if interesting event occured.
+ // By default, start relistening notifications. Stop only if interesting event occurred.
iWaitingCommsDatabaseNotifications = true;
RDbNotifier::TEvent event = STATIC_CAST(RDbNotifier::TEvent, iStatus.Int());
switch (event) {
diff --git a/src/bearer/qnetworksession_s60_p.cpp b/src/bearer/qnetworksession_s60_p.cpp
index 02f6a002d0..e209d7480c 100644
--- a/src/bearer/qnetworksession_s60_p.cpp
+++ b/src/bearer/qnetworksession_s60_p.cpp
@@ -726,7 +726,7 @@ void QNetworkSessionPrivate::Error(TInt /*aError*/)
{
#ifdef QT_BEARERMGMT_SYMBIAN_DEBUG
qDebug() << "QNS this : " << QString::number((uint)this) << " - "
- << "roaming Error() occured, isOpen is: " << isOpen;
+ << "roaming Error() occurred, isOpen is: " << isOpen;
#endif
if (isOpen) {
isOpen = false;
@@ -1018,7 +1018,7 @@ void QNetworkSessionPrivate::RunL()
TInt error = KErrNone;
QNetworkConfiguration newActiveConfig = activeConfiguration();
if (!newActiveConfig.isValid()) {
- // RConnection startup was successfull but no configuration
+ // RConnection startup was successful but no configuration
// was found. That indicates that user has chosen to create a
// new WLAN configuration (from scan results), but that new
// configuration does not have access to Internet (Internet
diff --git a/src/contacts/engines/qcontactmemorybackend.cpp b/src/contacts/engines/qcontactmemorybackend.cpp
index dabff8bf4f..05f21fcf9f 100644
--- a/src/contacts/engines/qcontactmemorybackend.cpp
+++ b/src/contacts/engines/qcontactmemorybackend.cpp
@@ -176,7 +176,7 @@ QContactLocalId QContactMemoryEngine::selfContactId(QContactManager::Error* erro
/*! \reimp */
QContact QContactMemoryEngine::contact(const QContactLocalId& contactId, const QContactFetchHint& fetchHint, QContactManager::Error* error) const
{
- Q_UNUSED(fetchHint); // no optimisations are possible in the memory backend; ignore the fetch hint.
+ Q_UNUSED(fetchHint); // no optimizations are possible in the memory backend; ignore the fetch hint.
int index = d->m_contactIds.indexOf(contactId);
if (index != -1) {
// found the contact successfully.
@@ -209,7 +209,7 @@ QList<QContactLocalId> QContactMemoryEngine::contactIds(const QContactFilter& fi
/*! \reimp */
QList<QContact> QContactMemoryEngine::contacts(const QContactFilter& filter, const QList<QContactSortOrder>& sortOrders, const QContactFetchHint& fetchHint, QContactManager::Error* error) const
{
- Q_UNUSED(fetchHint); // no optimisations are possible in the memory backend; ignore the fetch hint.
+ Q_UNUSED(fetchHint); // no optimizations are possible in the memory backend; ignore the fetch hint.
Q_UNUSED(error);
QList<QContact> sorted;
diff --git a/src/gallery/qgalleryqueryrequest.cpp b/src/gallery/qgalleryqueryrequest.cpp
index 5e63f3b6f8..9e0535332f 100644
--- a/src/gallery/qgalleryqueryrequest.cpp
+++ b/src/gallery/qgalleryqueryrequest.cpp
@@ -301,7 +301,7 @@ void QGalleryQueryRequest::setOffset(int offset)
/*!
\property QGalleryQueryRequest::limit
- \brief the maximimum number of items a query should return.
+ \brief the maximum number of items a query should return.
*/
int QGalleryQueryRequest::limit() const
diff --git a/src/messaging/eventloggerengine_maemo.cpp b/src/messaging/eventloggerengine_maemo.cpp
index d4dc280294..606325e401 100644
--- a/src/messaging/eventloggerengine_maemo.cpp
+++ b/src/messaging/eventloggerengine_maemo.cpp
@@ -362,7 +362,7 @@ void EventLoggerEngine::notification(int eventId, QString service,QMessageStoreP
} else if (service== "RTCOM_EL_SERVICE_CHAT") {
msg.setType(QMessage::InstantMessage);
} else {
- msg.setType(QMessage::NoType); // Other type, as eample voice calll
+ msg.setType(QMessage::NoType); // Other type, as example voice calll
}
}
else if (!messageRetrieved) {
diff --git a/src/messaging/modestengine_maemo.cpp b/src/messaging/modestengine_maemo.cpp
index acb3186cbe..cba373d76b 100644
--- a/src/messaging/modestengine_maemo.cpp
+++ b/src/messaging/modestengine_maemo.cpp
@@ -3359,7 +3359,7 @@ INotifyWatcher::INotifyWatcher()
// => returned file descriptor is associated with
// a new inotify event queue
// O_CLOEXEC flag makes sure that file descriptor
- // is closed if execution is transfered
+ // is closed if execution is transferred
// from this process to a new program
// (Check more info from 'execve' documentation)
#ifdef IN_CLOEXEC
diff --git a/src/messaging/qmessagefilter_win.cpp b/src/messaging/qmessagefilter_win.cpp
index 1584b41627..e01d674594 100644
--- a/src/messaging/qmessagefilter_win.cpp
+++ b/src/messaging/qmessagefilter_win.cpp
@@ -1800,7 +1800,7 @@ QMessageFilter QMessageFilterPrivate::bySender(const QString &value, QMessageDat
QMessageAddress::parseEmailAddress(sender, &name, &address, &suffix, &startDelimeterFound);
if (startDelimeterFound) {
QMessageFilter result(QMessageFilterPrivate::from(QMessageFilterPrivate::SenderAddress, QVariant(address), QMessageDataComparator::Equal));
- // An exact match requires a Suffix comparision (which is not supported by MAPI) rather than just an Includes
+ // An exact match requires a Suffix comparison (which is not supported by MAPI) rather than just an Includes
// Furthermore this seems to trigger some kind of MAPI restriction bug, results are being missed, so comment out for now
// result &= QMessageFilterPrivate::from(QMessageFilterPrivate::SenderName, QVariant(name), QMessageDataComparator::Equal);
if (cmp == QMessageDataComparator::Equal) {
@@ -1858,7 +1858,7 @@ QMessageFilter QMessageFilterPrivate::bySender(const QString &value, QMessageDat
result &= QMessageFilterPrivate::from(QMessageFilterPrivate::SenderAddress, QVariant(address), QMessageDataComparator::Includes);
}
- // An exact match requires a Suffix comparision (which is not supported by MAPI) rather than just an Includes
+ // An exact match requires a Suffix comparison (which is not supported by MAPI) rather than just an Includes
// Furthermore this seems to trigger some kind of MAPI restriction bug, results are being missed, so comment out for now
// result &= QMessageFilterPrivate::from(QMessageFilterPrivate::SenderName, QVariant(name), QMessageDataComparator::Includes);
@@ -1910,7 +1910,7 @@ QMessageFilter QMessageFilter::byRecipients(const QString &value, QMessageDataCo
result &= QMessageFilterPrivate::from(QMessageFilterPrivate::RecipientAddress, QVariant(address), QMessageDataComparator::Includes);
}
- // Need additional matches check, this should be a Suffix comparision rather than just an Includes
+ // Need additional matches check, this should be a Suffix comparison rather than just an Includes
result &= QMessageFilterPrivate::from(QMessageFilterPrivate::RecipientName, QVariant(name), QMessageDataComparator::Includes);
if (cmp == QMessageDataComparator::Includes) {
diff --git a/src/messaging/qmessageservice.cpp b/src/messaging/qmessageservice.cpp
index 69a18a5a23..e363b9007d 100644
--- a/src/messaging/qmessageservice.cpp
+++ b/src/messaging/qmessageservice.cpp
@@ -97,7 +97,7 @@ QTM_BEGIN_NAMESPACE
\value InactiveState The operation has not yet begun execution.
\value ActiveState The operation is currently executing.
\value CanceledState The operation was canceled.
- \value FinishedState The operation has finished execution; succesfully completed or otherwise.
+ \value FinishedState The operation has finished execution; successfully completed or otherwise.
*/
/*!
diff --git a/src/messaging/qmessageservice_win.cpp b/src/messaging/qmessageservice_win.cpp
index 288aed64d6..f520c5be41 100644
--- a/src/messaging/qmessageservice_win.cpp
+++ b/src/messaging/qmessageservice_win.cpp
@@ -390,7 +390,7 @@ bool QMessageServicePrivate::send(const QMessage& message, bool showComposer)
QMessage outgoing(message);
- //ensure the message is marked read otherwise MapiForm displays the message as incomming
+ //ensure the message is marked read otherwise MapiForm displays the message as incoming
outgoing.setStatus(QMessage::Read,true);
//set default account if unset
@@ -630,7 +630,7 @@ bool QMessageServicePrivate::markForDownload(const QMessageId& id, bool includeA
mapiRelease(message);
- //TODO investigate possiblity of interacting with mapi transport directly
+ //TODO investigate possibility of interacting with mapi transport directly
/*
QString transportName = mapiStore->transportName();
if(transportName.isEmpty())
diff --git a/src/messaging/qmtmengine_symbian.cpp b/src/messaging/qmtmengine_symbian.cpp
index deb2116ab2..661a4ba92b 100644
--- a/src/messaging/qmtmengine_symbian.cpp
+++ b/src/messaging/qmtmengine_symbian.cpp
@@ -2565,7 +2565,7 @@ bool CMTMEngine::isGsm0338CompatibleUnicodeCharacter(TUint16 aValue)
for (int i=0; i < 128; i++) {
if (KSMS0338UnicodeChars[i] == aValue) {
if (aValue == 0x00A0) {
- // Escape chatacter <=> character 0x1B in GSM 03.38
+ // Escape character <=> character 0x1B in GSM 03.38
// character set
// => Can't be mapped to GSM 03.38 character set
// <=> KEscapedSMS0338UnicodeChars array contains
diff --git a/src/messaging/tpsessionaccount.cpp b/src/messaging/tpsessionaccount.cpp
index 019d0e20ff..8eb63140a8 100644
--- a/src/messaging/tpsessionaccount.cpp
+++ b/src/messaging/tpsessionaccount.cpp
@@ -70,7 +70,7 @@
/**
* \fn void TpSessionAccount::messageReceived(const Tp::ReceivedMessage &,TpSessionAccount *);
*
- * Emitted when any of Account Managers recived message
+ * Emitted when any of Account Managers received message
*
* \param Tp::ReceivedMessage Message received
* \param TpSessionAccount pointer to account received message
diff --git a/src/messaging/tpsessionchannel.cpp b/src/messaging/tpsessionchannel.cpp
index e3447e3199..0af8c65129 100644
--- a/src/messaging/tpsessionchannel.cpp
+++ b/src/messaging/tpsessionchannel.cpp
@@ -71,7 +71,7 @@
/**
* \fn void TpSessionChannel::messageReceived(const Tp::ReceivedMessage &,TpSessionConnection *);
*
- * Emitted when any of Account Managers recived message
+ * Emitted when any of Account Managers received message
*
* \param Tp::ReceivedMessage Message received
* \param TpSessionChannel pointer to channel received message
diff --git a/src/messaging/win32wce/qmailmessage.cpp b/src/messaging/win32wce/qmailmessage.cpp
index f994b9f3a3..5cce53bacd 100644
--- a/src/messaging/win32wce/qmailmessage.cpp
+++ b/src/messaging/win32wce/qmailmessage.cpp
@@ -700,7 +700,7 @@ static QByteArray generateEncodedParameter(const QByteArray& charset, const QByt
int index = result.indexOf('*');
if (index != -1)
{
- // If no language is specfied, use the extracted part
+ // If no language is specified, use the extracted part
if (lang.isEmpty())
lang = result.mid(index + 1);
@@ -6390,7 +6390,7 @@ void QMailMessagePrivate::deserialize(Stream &stream)
from QMailMessagePartContainer.
Messages can be added to the QMailStore, or retrieved from the store via their QMailMessageId
- identifier. The QMailMessage object also provides acces to any relevant meta data
+ identifier. The QMailMessage object also provides access to any relevant meta data
describing the message, using the functions inherited from QMailMessageMetaData.
A message may be serialized to a QDataStream, or returned as a QByteArray using toRfc2822().
diff --git a/src/messaging/win32wce/qmailmessagefwd.cpp b/src/messaging/win32wce/qmailmessagefwd.cpp
index 9681d00bc3..a77111c4c9 100644
--- a/src/messaging/win32wce/qmailmessagefwd.cpp
+++ b/src/messaging/win32wce/qmailmessagefwd.cpp
@@ -267,6 +267,6 @@
/*!
\typedef QMailMessageFwd::MessageChunk
- This type defines a single chunk in a sequence of partitioned ouput data.
+ This type defines a single chunk in a sequence of partitioned output data.
*/
diff --git a/src/multimedia/qcamera.cpp b/src/multimedia/qcamera.cpp
index 444a94a7b7..670a328d03 100644
--- a/src/multimedia/qcamera.cpp
+++ b/src/multimedia/qcamera.cpp
@@ -566,7 +566,7 @@ void QCamera::setCaptureMode(QCamera::CaptureMode mode)
Starts the camera.
State is changed to QCamera::ActiveState if camera is started
- succesfully, otherwise error() signal is emited.
+ successfully, otherwise error() signal is emitted.
While the camera state is changed to QCamera::ActiveState,
starting the camera service can be asynchronous with the actual
@@ -700,8 +700,8 @@ QCamera::LockStatus QCamera::lockStatus(QCamera::LockType lockType) const
The camera settings are usually locked before taking one or multiple still images,
in responce to the shutter button being half pressed.
- The QCamera::locked() signal is emited when camera settings are successfully locked,
- otherwise QCamera::lockFailed() is emited.
+ The QCamera::locked() signal is emitted when camera settings are successfully locked,
+ otherwise QCamera::lockFailed() is emitted.
QCamera also emits lockStatusChanged(QCamera::LockType, QCamera::LockStatus)
on individual lock status changes and lockStatusChanged(QCamera::LockStatus) signal on composite status changes.
@@ -916,7 +916,7 @@ void QCamera::unlock()
The locked state usually means the requested parameter stays the same,
except of the cases when the parameter is requested to be constantly updated.
- For example in continous focusing mode, the focus is considered locked as long
+ For example in continuous focusing mode, the focus is considered locked as long
and the object is in focus, even while the actual focusing distance may be constantly changing.
*/
diff --git a/src/multimedia/qcameracontrol.cpp b/src/multimedia/qcameracontrol.cpp
index 5c5f55e307..1aef4e518c 100644
--- a/src/multimedia/qcameracontrol.cpp
+++ b/src/multimedia/qcameracontrol.cpp
@@ -124,7 +124,7 @@ QCameraControl::~QCameraControl()
Signal emitted when the camera \a state changes.
In most cases the state chage is caused by QCameraControl::setState(),
- but if critical error has occured the state changes to QCamera::UnloadedState.
+ but if critical error has occurred the state changes to QCamera::UnloadedState.
*/
/*!
diff --git a/src/multimedia/qcameraexposure.cpp b/src/multimedia/qcameraexposure.cpp
index f7cfcf4815..a5668c5aea 100644
--- a/src/multimedia/qcameraexposure.cpp
+++ b/src/multimedia/qcameraexposure.cpp
@@ -413,7 +413,7 @@ qreal QCameraExposure::aperture() const
/*!
Returns the list of aperture values camera supports.
The apertures list can change depending on the focal length,
- in such a case the apertureRangeChanged() signal is emited.
+ in such a case the apertureRangeChanged() signal is emitted.
If the camera supports arbitrary aperture values within the supported range,
*\a continuous is set to true, otherwise *\a continuous is set to false.
diff --git a/src/multimedia/qcameraexposurecontrol.cpp b/src/multimedia/qcameraexposurecontrol.cpp
index 1a194ee45a..7e70c5882d 100644
--- a/src/multimedia/qcameraexposurecontrol.cpp
+++ b/src/multimedia/qcameraexposurecontrol.cpp
@@ -140,7 +140,7 @@ Set the metering mode to \a mode.
\value Aperture
Lens aperture is specified as an qreal F number.
The supported apertures list can change depending on the focal length,
- in such a case the exposureParameterRangeChanged() signal is emited.
+ in such a case the exposureParameterRangeChanged() signal is emitted.
\value ShutterSpeed
Shutter speed in seconds, specified as qreal.
\value ExposureCompensation
@@ -165,7 +165,7 @@ Set the metering mode to \a mode.
\value ReadOnly
Parameters are read only.
\value ContinuousRange
- Parameters are continous in their range.
+ Parameters are continuous in their range.
*/
/*!
@@ -197,7 +197,7 @@ Set the metering mode to \a mode.
\fn bool QCameraExposureControl::setExposureParameter(ExposureParameter parameter, const QVariant& value)
Set the exposure \a parameter to \a value.
- If a null or invalid QVariant is passed, backend should choose the value automaticaly,
+ If a null or invalid QVariant is passed, backend should choose the value automatically,
and if possible report the actual value to user with QCameraExposureControl::exposureParameter().
Returns true if parameter is supported and value is correct.
diff --git a/src/multimedia/qcamerafocus.cpp b/src/multimedia/qcamerafocus.cpp
index 066e6d6618..e054b1ec7c 100644
--- a/src/multimedia/qcamerafocus.cpp
+++ b/src/multimedia/qcamerafocus.cpp
@@ -416,7 +416,7 @@ void QCameraFocus::zoomTo(qreal optical, qreal digital)
/*!
\enum QCameraFocus::FocusPointMode
- \value FocusPointAuto Automaticaly select one or multiple focus points.
+ \value FocusPointAuto Automatically select one or multiple focus points.
\value FocusPointCenter Focus to the frame center.
\value FocusPointFaceDetection Focus on faces in the frame.
\value FocusPointCustom Focus to the custom point, defined by QCameraFocus::customFocusPoint property.
@@ -454,7 +454,7 @@ void QCameraFocus::zoomTo(qreal optical, qreal digital)
/*!
\fn QCameraFocus::focusZonesChanged()
- Signal is emited when the set of zones, camera focused on is changed.
+ Signal is emitted when the set of zones, camera focused on is changed.
Usually the zones list is changed when the camera is focused.
*/
diff --git a/src/multimedia/qcamerafocuscontrol.cpp b/src/multimedia/qcamerafocuscontrol.cpp
index 76e61dbda7..282296137b 100644
--- a/src/multimedia/qcamerafocuscontrol.cpp
+++ b/src/multimedia/qcamerafocuscontrol.cpp
@@ -224,7 +224,7 @@ QCameraFocusControl::~QCameraFocusControl()
/*!
\fn QCameraFocusControl::focusZonesChanged()
- Signal is emited when the set of zones, camera focused on is changed.
+ Signal is emitted when the set of zones, camera focused on is changed.
Usually the zones list is changed when the camera is focused.
diff --git a/src/multimedia/qcameraimagecapture.cpp b/src/multimedia/qcameraimagecapture.cpp
index 97fdf629aa..3d68e826dd 100644
--- a/src/multimedia/qcameraimagecapture.cpp
+++ b/src/multimedia/qcameraimagecapture.cpp
@@ -469,20 +469,20 @@ void QCameraImageCapture::cancelCapture()
/*!
\fn QCameraImageCapture::imageExposed(int id)
- Signal emited when the frame with request \a id was exposed.
+ Signal emitted when the frame with request \a id was exposed.
*/
/*!
\fn QCameraImageCapture::imageCaptured(int id, const QImage &preview);
- Signal emited when the frame with request \a id was captured, but not processed and saved yet.
+ Signal emitted when the frame with request \a id was captured, but not processed and saved yet.
Frame \a preview can be displayed to user.
*/
/*!
\fn QCameraImageCapture::imageSaved(int id, const QString &fileName)
- Signal emited when the frame with request \a id was saved to \a fileName.
+ Signal emitted when the frame with request \a id was saved to \a fileName.
*/
diff --git a/src/multimedia/qcameraimageprocessingcontrol.cpp b/src/multimedia/qcameraimageprocessingcontrol.cpp
index 0b3447ca74..2b40d4c6a0 100644
--- a/src/multimedia/qcameraimageprocessingcontrol.cpp
+++ b/src/multimedia/qcameraimageprocessingcontrol.cpp
@@ -51,7 +51,7 @@ QT_BEGIN_NAMESPACE
\brief The QCameraImageProcessingControl class provides an abstract class
- for controling image processing parameters, like white balance,
+ for controlling image processing parameters, like white balance,
contrast, saturation, sharpening and denoising.
The interface name of QCameraImageProcessingControl is \c com.nokia.Qt.QCameraImageProcessingControl/1.0 as
diff --git a/src/multimedia/qmediabindableinterface.cpp b/src/multimedia/qmediabindableinterface.cpp
index 5dd4e156b6..6f048a9900 100644
--- a/src/multimedia/qmediabindableinterface.cpp
+++ b/src/multimedia/qmediabindableinterface.cpp
@@ -65,7 +65,7 @@ QMediaBindableInterface::~QMediaBindableInterface()
/*!
\fn QMediaBindableInterface::mediaObject() const;
- Return the currenty attached media object.
+ Return the currently attached media object.
*/
diff --git a/src/multimedia/qmediaobject.cpp b/src/multimedia/qmediaobject.cpp
index e39126f50a..41787d89bd 100644
--- a/src/multimedia/qmediaobject.cpp
+++ b/src/multimedia/qmediaobject.cpp
@@ -143,7 +143,7 @@ void QMediaObject::setNotifyInterval(int milliSeconds)
This method establishes a relationship between the media object and a
helper object. The nature of the relationship depends on both parties. This
- methods returns true if the helper was succesfully bound, false otherwise.
+ methods returns true if the helper was successfully bound, false otherwise.
The object passed must implement the QMediaBindableInterface interface.
diff --git a/src/multimedia/qmediaplayer.cpp b/src/multimedia/qmediaplayer.cpp
index 08c137bb5a..ea85496ca9 100644
--- a/src/multimedia/qmediaplayer.cpp
+++ b/src/multimedia/qmediaplayer.cpp
@@ -1020,7 +1020,7 @@ void QMediaPlayer::setVideoOutput(QGraphicsVideoItem *output)
\value StreamPlayback
The player is expected to play QIODevice based streams.
If passed to QMediaPlayer constructor, the service supporting
- streams playback will be choosen.
+ streams playback will be chosen.
*/
#include "moc_qmediaplayer.cpp"
diff --git a/src/multimedia/qmediaplayercontrol.cpp b/src/multimedia/qmediaplayercontrol.cpp
index 49f23e887d..5d0a7bace2 100644
--- a/src/multimedia/qmediaplayercontrol.cpp
+++ b/src/multimedia/qmediaplayercontrol.cpp
@@ -356,7 +356,7 @@ QMediaPlayerControl::QMediaPlayerControl(QObject *parent):
Stops playback of the current media.
- If succesful the player control will immediately enter the \l {QMediaPlayer::StoppedState}
+ If successful the player control will immediately enter the \l {QMediaPlayer::StoppedState}
{stopped} state.
*/
diff --git a/src/multimedia/qmediaplaylistcontrol.cpp b/src/multimedia/qmediaplaylistcontrol.cpp
index efdaef8323..21823e5597 100644
--- a/src/multimedia/qmediaplaylistcontrol.cpp
+++ b/src/multimedia/qmediaplaylistcontrol.cpp
@@ -178,19 +178,19 @@ QMediaPlaylistControl::~QMediaPlaylistControl()
/*!
\fn QMediaPlaylistControl::playlistProviderChanged()
- Signal emited when the playlist provider has changed.
+ Signal emitted when the playlist provider has changed.
*/
/*!
\fn QMediaPlaylistControl::currentIndexChanged(int position)
- Signal emited when the playlist \a position is changed.
+ Signal emitted when the playlist \a position is changed.
*/
/*!
\fn QMediaPlaylistControl::playbackModeChanged(QMediaPlaylist::PlaybackMode mode)
- Signal emited when the playback \a mode is changed.
+ Signal emitted when the playback \a mode is changed.
*/
/*!
diff --git a/src/multimedia/qmediaplaylistioplugin.cpp b/src/multimedia/qmediaplaylistioplugin.cpp
index 79d5cfb8b7..9d4fcc9861 100644
--- a/src/multimedia/qmediaplaylistioplugin.cpp
+++ b/src/multimedia/qmediaplaylistioplugin.cpp
@@ -101,7 +101,7 @@ QMediaPlaylistWriter::~QMediaPlaylistWriter()
Writes an item of \a media to a playlist file.
- Returns true if the media was written succesfully; and false otherwise.
+ Returns true if the media was written successfully; and false otherwise.
*/
/*!
diff --git a/src/multimedia/qmediaplaylistprovider.cpp b/src/multimedia/qmediaplaylistprovider.cpp
index 5ffc46369c..1564b3e9a7 100644
--- a/src/multimedia/qmediaplaylistprovider.cpp
+++ b/src/multimedia/qmediaplaylistprovider.cpp
@@ -130,7 +130,7 @@ bool QMediaPlaylistProvider::load(QIODevice * device, const char *format)
Saves the contents of a playlist to a URL \a location. If no playlist \a format is specified
the writer will inspect the URL to guess the format.
- Returns true if the playlist was saved succesfully; and false otherwise.
+ Returns true if the playlist was saved successfully; and false otherwise.
*/
bool QMediaPlaylistProvider::save(const QUrl &location, const char *format)
{
@@ -142,7 +142,7 @@ bool QMediaPlaylistProvider::save(const QUrl &location, const char *format)
/*!
Saves the contents of a playlist to an I/O \a device in the specified \a format.
- Returns true if the playlist was saved succesfully; and false otherwise.
+ Returns true if the playlist was saved successfully; and false otherwise.
*/
bool QMediaPlaylistProvider::save(QIODevice * device, const char *format)
{
diff --git a/src/multimedia/qmediaplaylistsourcecontrol.cpp b/src/multimedia/qmediaplaylistsourcecontrol.cpp
index 626332cbf1..2db83a88c6 100644
--- a/src/multimedia/qmediaplaylistsourcecontrol.cpp
+++ b/src/multimedia/qmediaplaylistsourcecontrol.cpp
@@ -116,7 +116,7 @@ QMediaPlaylistSourceControl::~QMediaPlaylistSourceControl()
/*!
\fn QMediaPlaylistSourceControl::playlistChanged(QMediaPlaylist* playlist)
- Signal emited when the playlist has changed to \a playlist.
+ Signal emitted when the playlist has changed to \a playlist.
*/
#include "moc_qmediaplaylistsourcecontrol.cpp"
diff --git a/src/multimedia/qmediastreamscontrol.cpp b/src/multimedia/qmediastreamscontrol.cpp
index ec5cca754e..b1d8d313f4 100644
--- a/src/multimedia/qmediastreamscontrol.cpp
+++ b/src/multimedia/qmediastreamscontrol.cpp
@@ -138,13 +138,13 @@ QMediaStreamsControl::~QMediaStreamsControl()
/*!
\fn QMediaStreamsControl::streamsChanged()
- The signal is emited when the available streams list is changed.
+ The signal is emitted when the available streams list is changed.
*/
/*!
\fn QMediaStreamsControl::activeStreamsChanged()
- The signal is emited when the active streams list is changed.
+ The signal is emitted when the active streams list is changed.
*/
#include "moc_qmediastreamscontrol.cpp"
diff --git a/src/multimedia/qradiotunercontrol.cpp b/src/multimedia/qradiotunercontrol.cpp
index 7b02a0e32d..06d0c38c24 100644
--- a/src/multimedia/qradiotunercontrol.cpp
+++ b/src/multimedia/qradiotunercontrol.cpp
@@ -320,7 +320,7 @@ QRadioTunerControl::~QRadioTunerControl()
/*!
\fn void QRadioTunerControl::error(QRadioTuner::Error error)
- Signals that an \a error has occured.
+ Signals that an \a error has occurred.
*/
#include "moc_qradiotunercontrol.cpp"
diff --git a/plugins/organizer/symbian/tsrc/tst_recurringitems/tst_recurringitems.cpp b/plugins/organizer/symbian/tsrc/tst_recurringitems/tst_recurringitems.cpp
index c90718cb4d..2f0ea7c687 100644
--- a/plugins/organizer/symbian/tsrc/tst_recurringitems/tst_recurringitems.cpp
+++ b/plugins/organizer/symbian/tsrc/tst_recurringitems/tst_recurringitems.cpp
@@ -594,7 +594,7 @@ void tst_recurringItems::addItemsMonthlyRecurrence(QString managerName, QString
<< QDateTime::currentDateTime().addSecs(3600)
<< rrule;
// Every other Month on first and last Sunday for 10 occurances
rrule = QOrganizerRecurrenceRule(); // reset
rrule.setFrequency(QOrganizerRecurrenceRule::Monthly);
rrule.setLimit(10);
@@ -606,14 +606,14 @@ void tst_recurringItems::addItemsMonthlyRecurrence(QString managerName, QString
positions.insert(1);
positions.insert(-1);
rrule.setPositions(positions);
- QTest::newRow(QString("[%1] Every other Month on first and last Sunday for 10 occurances").arg(managerName).toLatin1().constData())
+ QTest::newRow(QString("[%1] Every other Month on first and last Sunday for 10 occurrences").arg(managerName).toLatin1().constData())
<< managerName
<< QString("monthly 2")
<< itemType
<< QDateTime::currentDateTime().addSecs(3600)
<< rrule;
// Every third Month on first and third Sunday for 10 occurances
rrule = QOrganizerRecurrenceRule(); // reset
rrule.setFrequency(QOrganizerRecurrenceRule::Monthly);
rrule.setLimit(10);
@@ -625,7 +625,7 @@ void tst_recurringItems::addItemsMonthlyRecurrence(QString managerName, QString
positions.insert(1);
positions.insert(3);
rrule.setPositions(positions);
- QTest::newRow(QString("[%1] Every third Month on first and third Sunday for 10 occurances").arg(managerName).toLatin1().constData())
+ QTest::newRow(QString("[%1] Every third Month on first and third Sunday for 10 occurrences").arg(managerName).toLatin1().constData())
<< managerName
<< QString("monthly 3")
<< itemType
@@ -789,7 +789,7 @@ void tst_recurringItems::addItemsYearlyRecurrence(QString managerName, QString i
<< QDateTime::currentDateTime().addSecs(3600)
<< rrule;
// Every year for 3 occurances
rrule = QOrganizerRecurrenceRule();
rrule.setFrequency(QOrganizerRecurrenceRule::Yearly);
rrule.setLimit(3);
@@ -896,7 +896,7 @@ void tst_recurringItems::addItemsYearlyRecurrence(QString managerName, QString i
/* TODO: Enable the following test cases and implement them on symbian backend
//Every year in january and march for 4 occurances
// TODO: Symbian calendar server does not allow setting a yearly recurring
// event with "months" set but without setting "day of month"
rrule = QOrganizerRecurrenceRule();
@@ -913,7 +913,7 @@ void tst_recurringItems::addItemsYearlyRecurrence(QString managerName, QString i
<< QDateTime::currentDateTime().addSecs(3600)
<< rrule;
//Every other year in january,feburary and march for 4 occurances
rrule = QOrganizerRecurrenceRule();
rrule.setFrequency(QOrganizerRecurrenceRule::Yearly);
rrule.setLimit(4);
@@ -930,7 +930,7 @@ void tst_recurringItems::addItemsYearlyRecurrence(QString managerName, QString i
<< QDateTime::currentDateTime().addSecs(3600)
<< rrule;
//Every 3rd year on 1st,100th and 200th day for 10 occurances
rrule = QOrganizerRecurrenceRule();
rrule.setFrequency(QOrganizerRecurrenceRule::Yearly);
rrule.setLimit(10);
@@ -940,7 +940,7 @@ void tst_recurringItems::addItemsYearlyRecurrence(QString managerName, QString i
daysOfYear.insert(100);
daysOfYear.insert(200);
rrule.setDaysOfYear(daysOfYear);
- QTest::newRow(QString("[%1] every 3rd year on 1st,100th and 200th day for 10 occurances").arg(managerName).toLatin1().constData())
+ QTest::newRow(QString("[%1] every 3rd year on 1st,100th and 200th day for 10 occurrences").arg(managerName).toLatin1().constData())
<< managerName
<< QString("yearly 8")
<< itemType
@@ -999,7 +999,7 @@ void tst_recurringItems::addItemsYearlyRecurrence(QString managerName, QString i
daysOfMonth.insert(1);
rrule.setDaysOfMonth(daysOfMonth);
rrule.setLimit(4);
//Occurs every 1st day of the month for 4 occurances
QTest::newRow(QString("[%1] Days of Month=1, Count=4").arg(managerName).toLatin1().constData())
<< managerName
<< QString("yearly 12")
@@ -594,7 +594,7 @@ void tst_recurringItems::addItemsMonthlyRecurrence(QString managerName, QString
<< QDateTime::currentDateTime().addSecs(3600)
<< rrule;
- // Every other Month on first and last Sunday for 10 occurances
+ // Every other Month on first and last Sunday for 10 occurrences
rrule = QOrganizerRecurrenceRule(); // reset
rrule.setFrequency(QOrganizerRecurrenceRule::Monthly);
@@ -606,14 +606,14 @@ void tst_recurringItems::addItemsMonthlyRecurrence(QString managerName, QString
<< QDateTime::currentDateTime().addSecs(3600)
<< rrule;
- // Every third Month on first and third Sunday for 10 occurances
+ // Every third Month on first and third Sunday for 10 occurrences
rrule = QOrganizerRecurrenceRule(); // reset
rrule.setFrequency(QOrganizerRecurrenceRule::Monthly);
@@ -789,7 +789,7 @@ void tst_recurringItems::addItemsYearlyRecurrence(QString managerName, QString i
<< QDateTime::currentDateTime().addSecs(3600)
<< rrule;
- // Every year for 3 occurances
+ // Every year for 3 occurrences
rrule = QOrganizerRecurrenceRule();
rrule.setFrequency(QOrganizerRecurrenceRule::Yearly);
@@ -896,7 +896,7 @@ void tst_recurringItems::addItemsYearlyRecurrence(QString managerName, QString i
/* TODO: Enable the following test cases and implement them on symbian backend
- //Every year in january and march for 4 occurances
+ //Every year in january and march for 4 occurrences
// TODO: Symbian calendar server does not allow setting a yearly recurring
// event with "months" set but without setting "day of month"
@@ -913,7 +913,7 @@ void tst_recurringItems::addItemsYearlyRecurrence(QString managerName, QString i
<< QDateTime::currentDateTime().addSecs(3600)
<< rrule;
- //Every other year in january,feburary and march for 4 occurances
+ //Every other year in january,feburary and march for 4 occurrences
rrule = QOrganizerRecurrenceRule();
rrule.setFrequency(QOrganizerRecurrenceRule::Yearly);
@@ -930,7 +930,7 @@ void tst_recurringItems::addItemsYearlyRecurrence(QString managerName, QString i
<< QDateTime::currentDateTime().addSecs(3600)
<< rrule;
- //Every 3rd year on 1st,100th and 200th day for 10 occurances
+ //Every 3rd year on 1st,100th and 200th day for 10 occurrences
rrule = QOrganizerRecurrenceRule();
rrule.setFrequency(QOrganizerRecurrenceRule::Yearly);
@@ -999,7 +999,7 @@ void tst_recurringItems::addItemsYearlyRecurrence(QString managerName, QString i
rrule.setDaysOfMonth(daysOfMonth);
rrule.setLimit(4);
- //Occurs every 1st day of the month for 4 occurances
+ //Occurs every 1st day of the month for 4 occurrences
QTest::newRow(QString("[%1] Days of Month=1, Count=4").arg(managerName).toLatin1().constData())
<< managerName